;******************************************************************************************
;    COMPOSANT	:  ATMEL AVR 8 Bits (RISC)       AT90S8515 	Quartz = 3,6864 MHz
;    PROGRAMME	:  regul.ASM
;    VERSION	:  V1.4
;    DATE		:  29/07/00
;    DERNIERE MAJ.	:  05/10/00
;    DESCRIPTION	:  Gestion Aquastat : Temprature ambiante rgl par consigne
;			:  Modification Consigne en mode auto
;			:  Temprature Cdc rgl par clavier si mode manuel
;			:  Stabilisation de la Temp Ambiante par moyenne sur 32 lectures
;			:  Temps de dmarrage du Bruleur : 16 secondes au RESET (Manuel ou Automatique)
;			:  Coupure du circulateur en repos ( Cons_Amb+LIMITE_BASSE_AQUASTAT-HYSTERIS
;				-LIMITE_BASSE_CIRCUL)
;			:  Mise en fonctionnement des horodateurs (Repos et Bruleur)
;			:  Le rgulateur peut resortir du mode repos (si Cons_Amb=Tamb et Moins de 2h00 de repos)
;
;    AUTEUR	:  Igor GODI 	Email : igor.godi@freesbee.fr
;    TESTS	:  Fonctionne sur site
;******************************************************************************************
;			DIRECTIVES D'ASSEMBLAGE
;******************************************************************************************
	.device 	AT90S8515
	.include	"8515def.inc"	; Fichier de dfinition

;******************************************************************************************
;			CONSTANTES
;******************************************************************************************
.equ PORT_BRULEUR = PORTD	; Port de la commande de bruleur
.equ BROC_BRULEUR = PD1		; Broche de la commande de bruleur
.equ PORT_CIRCUL  = PORTD
.equ BROC_CIRCUL  = PD7		; Commande du circulateur

.equ HYSTERESIS   = 10		; +/- 5C autour de la temprature de consigne Cdc
.equ LIMITE_AQUA  = 110		; Aquastat limit  55C
.equ LIMITE_BASSE_AQUA = 18	; Limite basse 9C au dessus de Cons_Amb
.equ LIMITE_BASSE_CIRCUL = 2	; Circulateur coup  1C en dessous mini Aquastat (-HYSTERESIS)
.equ Tps_Eval	  = 1		; Evaluation de situation toutes les 30mns
.equ Nb_Cons_Moins  = 10	; Doit trouver 10/16 fois Cons_Amb-0,5C pour activer la consigne basse
.equ Nb_Cons_Plus   = 05	; Doit trouver 5/16 fois Cons_Amb+0,5C pour activer la consigne haute
.equ MAXI_REPLI_REPOS = 4	; la sortie de repos  Tamb=Cons_Amb est posible dans un temps de moins de 1h30

;******************************************************************************************
;			PORTS D'ENTREES/SORTIES
;******************************************************************************************
;________________________ CONFIGURATION PORT A __________________________________________
; Port A :	(I/O)	=	Liaison		; Description
;-------
; A_0	(xxx)	=	xxxxxxx		; xxxxxxxxxxx
; A_1	(xxx)	=	xxxxxxx		; xxxxxxxxxxx
; A_2	(xxx)	=	xxxxxxx		; xxxxxxxxxxx
; A_3	(xxx)	=	xxxxxxx		; xxxxxxxxxxx
; A_4	(xxx)	=	xxxxxxx		; Fil xxxxxxx
; A_5	(xxx)	=	xxxxxxx		; Fil xxxxxxx
; A_6	(xxx)	=	xxxxxxx		; Fil xxxxxxx
; A_7	(xxx)	=	xxxxxxx		; Fil xxxxxxx
;			  76543210
.equ	CONFIGA	  =	0b00000000

;________________________ CONFIGURATION PORT B __________________________________________
; Port B :	(I/O)	=	Liaison		; Description
;-------
; B_0	(Out)	=	D0 LCD		; Fils rlis au bus du LCD
; B_1	(Out)	=	D1 LCD		
; B_2	(Out)	=	D2 LCD		; Et au clavier Matric
; B_3	(Out)	=	D3 LCD		
; B_4	(Out)	=	D4 LCD		
; B_5	(Out)	=	D5 LCD		
; B_6	(Out)	=	D6 LCD		
; B_7	(Out)	=	D7 LCD		
;			  76543210
.equ	CONFIGB	  =	0b11111111

;________________________ CONFIGURATION PORT C __________________________________________
; Port C :	(I/O)	=	Liaison		; Description
;-------
; C_0	(xxx)	=	xxxxxxxx	; xxxxxxxxxxx
; C_1	(xxx)	=	xxxxxxxx	; xxxxxxxxxxx
; C_2	(xxx)	=	xxxxxxxx	; xxxxxxxxxxx
; C_3	(xxx)	=	xxxxxxxx	; xxxxxxxxxxx
; C_4	(xxx)	=	xxxxxxx		; Fil xxxxxxx
; C_5	(xxx)	=	xxxxxxx		; Fil xxxxxxx
; C_6	(xxx)	=	xxxxxxx		; Fil xxxxxxx
; C_7	(xxx)	=	xxxxxxx		; Fil xxxxxxx
;			  76543210
.equ	CONFIGC	  =	0b00000000

;________________________ CONFIGURATION PORT D __________________________________________
; Port D :	(I/O)	=	Liaison		; Description
;-------
; D_0	(in)	=	Sonde Ambiante	; Fil Dq DS1620
; D_1	(out)	=	Bruleur		; Fil Relais Bruleur
; D_2	(out)	=	Clk DS1620	; Fil Horloge DS1620
; D_3	(out)	=	Reset_DS1620	; Fil Reset DS1620
; D_4	(out)	=	E_LCD		; Fil Enable LCD
; D_5	(out)	=	RS_LCD		; Fil Signal Register Select LCD
; D_6	(in)	=	Sonde CDC	; Fil Dq DS1620
; D_7	(out)	=	Circulateur	; Fil Relais Circulateur
;			  76543210
.equ	CONFIGD	  =	0b10111110

;******************************************************************************************
;			AUTRES CONNEXIONS ELECTRIQUES
;******************************************************************************************
; Pour Le LCD :
;	* R/W LCD  la masse
;	* +5V LCD au +5Valim
;	* Masse LCD  la masse alim

;******************************************************************************************
;			DEFINITIONS DE REGISTRES
;******************************************************************************************
; Registres  usage Global :
;-------------------------
.def DivisionClavier	= r1	; compteur de division du clavier
.def Div_Temp		= r2	; Diviseur pour obtenir un envoi toutes les 10s
.def Div_Clign		= r3	; Diviseur pour obtenir les clignotements
.def Div_Minutes	= r4	; Diviseur pour obtenir les minutes
.def Div_DemiHeures	= r5	; Compteur de demis heures
.def CpTemps		= r6	; Dcompteur de temps (utilis en dmarrage)
.def Totaliseur		= r7	; Totaliseur de temps limit  4h (0  7x30mn minutes)
.def Hor_Heures		= r8	; Heures de l'horloge
.def Hor_Minutes	= r9	; Minutes de l'horloge
.def Hor_Secondes	= r10	; Secondes de l'horloge

.def DRAPEAU2	= r21	; Registre destin  contenir des drapeaux 
			; B7 Clignotement 1: En fonction
			; B6 Sauvegarde de l'tat prcedent de Bruleur
			; B5 0: Ligne 1 1:Ligne 2 en curseur noir
			; B4 Mode de fonc 0:Auto  1:Manuel
			; B3 Flag Demmarage  1:Dmarrage
			; B2 Flag Rglage    1: Rglage au dmarrage
			; B1 Flag Moyenne    1: Moyenne utilisable pour travailler
			; B0 Accs au pages cran (4  7) : future ext.

   ; Communs  LCDCLAV.SUB :
.def Touche	= r22	; Registre qui contiendra le code rel de la touche enfonce du clavier
.def DRAPEAUX	= r23	; Registre destin  contenir des drapeaux (Commun LCDCLAV.SUB)
			; B7 (Ou LCD_Occupe) 0:Bus LCD Libre  ou   1: Bus LCD Occup
			; B6 Permet d'viter la rptition 	0: Pas de touche frapp avant
			;					1: Dja frapp
			; B5 Bruleur    0: Eteint
			;		1: Allum
			; B4 Test	0: Mode normal
			;		1: Test (Tempratures Temp_Amb,Temp_Cdc,Cons_Amb au clavier)
			; B3 Chauff	0: Inhibition bruleur
			; 		1: Bruleur en marche
			; B2 Marche	0: Arrt thermostat
			;		1: Rgulation en marche
			; B1,B0 Page Active sur LCD:
			; 0  0    Marche Normale (ou normale au repos)
			; 0  1    Future Ext (Niveau de cuve fuel)
			; 1  0    Mode (auto ou manuel)
			; 1  1    Future Ext (Modem)

.def xh		= r27		; Pointeur sur Table de moyenne
.def xl		= r26

; Registres  usage Local :
;------------------------
.def zh		= r31		; Pointeur Z  (Utilis pour pointer en FLASH)
.def zl		= r30

.def temp	= r16		; Registre temporaire


;******************************************************************************************
;			ORGANISATION RAM
;******************************************************************************************
.dseg
.org 	0x60
M_Temp_Amb: 	.BYTE 1		; Temprature ambiante MSB
L_Temp_Amb: 	.BYTE 1		; Temprature ambiante LSB

M_Temp_Cdc:	.BYTE 1		; Temprature corps de chauffe MSB
L_Temp_Cdc: 	.BYTE 1		; Temprature corps de chauffe LSB

Cons_Amb:	.BYTE 1		; Consigne de temprature ambiante
Cons_Cdc:	.BYTE 1		; Consigne de corps de chauffe

TableValeurs:	.BYTE 16       	; Moyenne  faire sur 16 octets (Temprature Ambiante)
Moyenne_Amb:	.BYTE 1		; Rsultat de la moyenne de Temprature ambiante

Tps_Bruleur:	.BYTE 3		; Memorisation HH:MM:SS du tps bruleur
Tps_Repos:	.BYTE 4		; Mmorisation HHHH:MM(:SS) du temps repos

;******************************************************************************************
;			ORGANISATION EEPROM
;******************************************************************************************
.eseg
.org	0x00
  ;	xxxx:	.DB	"xxxxx"


;******************************************************************************************
;			INTERRUPTIONS ET RESET
;******************************************************************************************
.cseg
.org	0x00
	rjmp 	RESET		; Vecteur RESET
	reti			; Interruption Externe 0
	reti			; Interruption Externe 1
	reti			; Capture Timer1
	rjmp	T1_COMPA	; Comparaison Timer1A
	reti			; Comparaison Timer1B
	reti			; Timer1 Overflow
	reti			; Timer0 Overflow
	reti			; Transfert SPI
	reti			; Reception RS232 complte
	reti			; Registre emission RS232 vide
	reti			; Emission RS232 complte
	reti			; Comparateur Analogique

;******************************************************************************************
;			PROGRAMME PRINCIPAL (RESET)
;******************************************************************************************
RESET :
;__________________________________ INITIALISATIONS _______________________________________
	;----------------- Initialisation de la pile --------------------------------------
	ldi 	temp,low(RAMEND)	; Pointe en fin de mmoire
	out 	SPL,temp
	ldi 	temp,high(RAMEND)	; Pointe en fin de mmoire
	out 	SPH,temp

	;----------------- Initialisation des ports ---------------------------------------
	ldi	temp, CONFIGA	; Init PORT A voir au dessus pour dfinition des broches
	out	DDRA,temp
	ldi	temp, CONFIGB	; Init PORT B voir au dessus pour dfinition des broches
	out	DDRB,temp
	ldi	temp, CONFIGC	; Init PORT C voir au dessus pour dfinition des broches
	out	DDRC,temp
	ldi	temp, CONFIGD	; Init PORT D voir au dessus pour dfinition des broches
	out	DDRD,temp

	;----------------- Initialisation des Timer (0 et 1) ------------------------------
		; TIMER 1 :
	ldi 	temp, high(0x0024)	; Poid fort registre de comparaison (si utilis)
	out	OCR1AH,temp
	ldi 	temp, low(0x0024)	; Poid faible registre de comparaison (si utilis)
	out	OCR1AL,temp		; Soit 10ms
	ldi	temp,0x00		; Utilisation de la broche de sortie 0C1 : Non
					; PWM : Arrt
	out 	TCCR1A,temp		
	ldi	temp,0x0D		; Rducteur de bruit : Non
					; Mode Comparaison (TCNT1=OCR1A=>RAZ) : Marche
					; Source horloge : Ck/1024=3600Hz
	out 	TCCR1B,temp		
		; INTERRUPTIONS DU TIMER
	ldi 	temp,0x40		; Timer1 : Comparaison A Activ (Pas B) 
					
	out 	TIMSK,temp

	;----------------- Initialisation Comparateur Analogique ---------------------------
	ldi 	temp,0x80		; Comparateur Analogique : Arrt
	out	ACSR,temp

	;----------------- Initialisation des registres ------------------------------------
	ldi DRAPEAUX,0x0C	; Pas de mode Test, Bruleur autoris, Regul en marche, 
				; Marche normale
	ldi DRAPEAU2,0x0C	; Dpart en mode Automatique, Dmarrage  faire (et rglage),
				; Moyenne non calcule

	ldi temp,40		; Consigne Rgulation sur 20C
	sts Cons_Amb,temp
	ldi temp,60		; consigne Cdc sur 30C
	sts Cons_Cdc,temp

	clr r16
	sts Tps_Bruleur,r16
	sts Tps_Bruleur+1,r16
	sts Tps_Bruleur+2,r16
	sts Tps_Repos,r16
	sts Tps_Repos+1,r16
	sts Tps_Repos+2,r16
	sts Tps_Repos+3,r16

	ldi xh,high(TableValeurs) ; Pointe sur la table de moyenne Temp_Amb
	ldi xl,low(TableValeurs)
	
	;----------------- Programmes d'Initialisation -------------------------------------
	rcall INIT_LCD		; Initialisation Afficheur LCD
	rcall INIT_CONFIG_LCD	; 2 lignes mode 8 bits

	rcall INIT_DS1620	; init des fils E/S du DS1620
	rcall CONFIG_DS1620	; Configuration DS1620
	rcall LANCE_CONV_DS1620	; Lance une conversion continue

;__________________________________ PROGRAMME PRINCIPAL ________________________________
	ldi zl,low(BV1*2)	; Afficher la ligne 1 Bienvenue
	ldi zh,high(BV1*2)	
	rcall Aff_Lg1

	ldi zl,low(BV2*2)	; Afficher la ligne 2 Bienvenue
	ldi zh,high(BV2*2)	
	rcall Aff_Lg2

	ldi r16,0x30		; Pause de 3s environ pour bienvenue
b1:	ldi r17,0xFF
b2:	ldi r18,0xFF
b3:	dec r18
	brne b3
	dec r17
	brne b2
	dec r16
	brne b1

	rcall Aff_Ecran		; Affichage de l'cran courant
	rcall Aff_Valeurs	; Affichage des valeurs

	;----------------- Autorisation des intrruptions ----------------------------------
	sei			; Autorisation des interruptions 

PRINC:	
	rjmp PRINC


;******************************************************************************************
;			ROUTINES D'INTERRUPTIONS
;******************************************************************************************
;______________________________________ TIMER1 COMPARAISON _____________________________
T1_COMPA:				; Rgl sur 10ms
					; Gestion Heure et Clavier
	push temp		; Empiler temp
	in temp,SREG
	push temp		; Empiler SREG

	;sei			; Permet de traiter d'autres interruptions

Clavier:				
	;----------------- Traitement du clavier ( ttes les 100ms) -------------------------
	inc DivisionClavier	; incrmente prdiviseur Clavier
	ldi temp,10		; scrutation toutes les 10x10ms = 100ms
	cp DivisionClavier,temp
	brne Fin_Clavier
	
	clr DivisionClavier	; repart  O
	rcall LitClavier	; Lecture du clavier (code Physique ou rel)
	cpi Touche,0x10
	breq Fin_Clavier	; Si pas de touche
	cpi Touche,0x20
	breq RetardLecture	; Si LCD Occup
	rjmp PriseDecision
RetardLecture:			; Permet de rescruter le Clavier toutes les 10ms si
				; le LCD occupait le bus dans la routine en cours
				; lors de l'appel du timer 1 : permet fluidit du clavier
	ldi temp,9
	mov DivisionClavier,temp	; R-Intrrogation du clavier dans 10ms
	ldi Touche,0x10		; permet d'viter de faire 2 tests
	rjmp Fin_Clavier

Fin_SecondeBIS: rjmp Fin_Seconde

	;----------------- Prises de dcisions Aprs acquistion Clavier --------------------
PriseDecision:
	rcall Gest_Clavier	; Gestion des infos du clavier 

Fin_Clavier:

	;----------------- Lecture T ------------------------------------------------------
Lect_Temp:
	ldi r16,100
	inc Div_Temp
	cp Div_Temp,r16		; 1 seconde ?
        brne Fin_SecondeBIS	; Si non fin
	clr Div_Temp		; Si Oui Div_Temp=0

Seconde:	
	ldi r16,60
	inc Div_Minutes
	cp Div_Minutes,r16	; 1 minutes
	brne Lire_Temp		; Si non va lire la temprature
	clr Div_Minutes		; Si Oui Div_Minutes=0
	ldi r16,30
	inc Div_DemiHeures
	cp Div_DemiHeures,r16	; 30mn ?
	brne Lire_Temp
	clr Div_DemiHeures
	tst CpTemps
	breq NoDec		; Si CpTemps=0 ne dcrmente pas
	dec CpTemps		; Dcremente le dcompteur de temps
NoDec:
	ldi r16,8
	cp Totaliseur,r16	; Arrt du totaliseur au bout de 4 heures (8x1/2h)
	breq Lire_Temp
	inc Totaliseur	
	
Lire_Temp:
	sbrs DRAPEAUX,4		; saut si mode test  actif
	rjmp lire		; Procdure de lecture si Test inactif
	sbr DRAPEAU2,0x02	; Permet de faire crore  une moyenne valide
	rjmp Memo_Temp		; Ne pas lire temp
Lire:
	rcall Lit_Temp		; Lecture Temprature
Memo_temp:
	lds r16,L_Temp_Amb
	st x+,r16		; Sauve la valeur de la temprature ambiante dans la table de moyenne
	cpi xl,low(TableValeurs+16)
	brne Cal_Moy
	cpi xh,high(TableValeurs+16) 	; Fin de Table ?
	brne Cal_Moy		     	; Si non calcule de suite la moyenne
	ldi xh,high(TableValeurs)    	; Si oui : Remet le pointeur  0
	ldi xl,low(TableValeurs)
	sbr DRAPEAU2,0x02	    	; Met  1 le Bit Moyenne
	; Le Comptage du nombre de fois ou apparait le seuil permet d'eviter les
	; parasites dues aux courant d'air
Cal_Moy:
	push xh				; Sauve le pointeur actuel
	push xl
	;--------- Recherche du nombre de fois que l'on a Cons_Amb+0,5C dans le buffer --
Valeur1:
	ldi xh,high(TableValeurs)    	; Si oui : Remet le pointeur  0
	ldi xl,low(TableValeurs)
	lds r17,Cons_Amb
	inc r17		
	clr r18		; R18 compte le nombre de fois qu'il y a Cons_Amb+0,5C	
Cont1:
	ld r16,x+	; Charger l'octet en mmoire
	cp r16,r17
	brlo NoInc1
	inc r18
NoInc1:
	cpi xl,low(TableValeurs+16)
	brne Cont1
	cpi xh,high(TableValeurs+16) 	; Fin de Table ?
	brne Cont1
	cpi r18,Nb_Cons_Plus
	brlo Valeur2			; Si assez de fois trouv
	sts Moyenne_Amb,r17		; Moyenne= Consigne+0,5C
	rjmp Fin_Moy
 
	;--------- Recherche du nombre de fois que l'on a Cons_Amb-0,5C dans le buffer --
Valeur2:
	ldi xh,high(TableValeurs)    	; Si oui : Remet le pointeur  0
	ldi xl,low(TableValeurs)
	lds r17,Cons_Amb
	dec r17		
	clr r18		; R18 compte le nombre de fois qu'il y a Cons_Amb-0,5C	
Cont2:
	ld r16,x+	; Charger l'octet en mmoire
	cp r17,r16
	brlo NoInc2
	inc r18
NoInc2:
	cpi xl,low(TableValeurs+16)
	brne Cont2
	cpi xh,high(TableValeurs+16) 	; Fin de Table ?
	brne Cont2
	cpi r18,Nb_Cons_Moins
	brlo Pas_Valeur			; Si assez de fois trouv
	sts Moyenne_Amb,r17		; Moyenne= Consigne-0,5C
	rjmp Fin_Moy

	;------------- Si aucune des deux consignes n'est apparue assez -----------------
Pas_Valeur:
	lds r16,Cons_Amb
	sts Moyenne_Amb,r16  ; Moyenne = Lecture directe du capteur

Fin_Moy:
	pop xl
	pop xh
Fin_Cal:

	;----------------- Affichage temprature en fonction de la page ---------------------
Affiche_Temp:
	rcall Aff_Valeurs	; Affichage des valeurs

	;------------------ Traitement de la consigne Cdc -----------------------------------
Trait_consigne:
	sbrs DRAPEAUX,2		; saut si thermostat en route
	rjmp Coupe_Tout		; Sinon arret bruleur, du Circulateur et pas de rgulation
	sbrs DRAPEAU2,1		; Saut si Moyenne Ambiante calcule (au bout de 32s)
	rjmp Coupe_Bruleur	; Sinon pilotage inhib jusque moyenne ambiante valide
	sbrs DRAPEAU2,4		; Pas de Traitement consigne Cdc si mode manuel
	rcall Trait_Auto	; Sinon lance le SP de traitement de consigne CDC

	;----------------- Coupure Automatique du Circulateur -------------------------------
	;----------------- Quel que soit le mode --------------------------------------------
	;----------------- Inhibe l'aquastat si ordonn -------------------------------------

Circulateur:	
	sbrc DRAPEAUX,3		; Possible que si Chauff=0 (Repos Activ)
	rjmp Fin_Circulateur	; Car la mise en marche  froid doit tre possible
	lds r17,Cons_Amb
	ldi r18,LIMITE_BASSE_AQUA-HYSTERESIS-LIMITE_BASSE_CIRCUL
	add r17,r18		; limite basse pour activer circulateur
	lds r16,L_Temp_Cdc	; Lire temprature corps de chauffe
	cp r17,r16
	brsh Coupe_Tout		; Si inferieur coupe le circulateur

Fin_Circulateur:

	;----------------- Rgulation de l'Aquastat -----------------------------------------
Aquastat:
	sbrs DRAPEAUX,3		; Saut si Bruleur autoris
	rjmp Coupe_Bruleur	; Sinon Arrt bruleur
	
	ldi r17,HYSTERESIS	; hystris
	lds r16,Cons_Cdc
	add r16,r17		; Ajoute Hystresis  la consigne
	lds r17,L_Temp_Cdc
	cp r17,r16		; compare Tcdc>=Cons_Cdc+Hyst/2
	brge Coupe_Bruleur	; Si oui coupe le bruleur

	ldi r17,HYSTERESIS	; Hystresis
	lds r16,Cons_Cdc
	sub r16,r17		; retire hysteresis
	lds r17,L_Temp_Cdc
	cp r16,r17		; Compare Tcdc=<Cons_Cdc-Hyst/2
	brge Allume_Bruleur	; Si oui allume Bruleur
	rjmp Fin_Aquastat	; si rien fin de traitement aquastat
	
Allume_Bruleur:
	sbi PORT_BRULEUR,BROC_BRULEUR		; Allumer bruleur
	sbr DRAPEAUX,0x20			; Agite Flag Bruleur
	sbi PORT_CIRCUL,BROC_CIRCUL		; Allumage Circulateur (Si pas activ)
	rjmp Fin_Aquastat

Coupe_Bruleur:
	cbi PORT_BRULEUR,BROC_BRULEUR		; Eteindre bruleur
	cbr DRAPEAUX,0x20			; Descendre Flag Bruleur
	rjmp Fin_Aquastat

Coupe_Tout:
	cbi PORT_BRULEUR,BROC_BRULEUR		; Eteindre bruleur
	cbr DRAPEAUX,0x20			; Descendre Flag Bruleur
	cbi PORT_CIRCUL,BROC_CIRCUL		; Coupure Circulateur

Fin_Aquastat:
	
	;------------- Modification des horodateurs ----------------------------------
Horodateur:
	sbrs DRAPEAUX,5 	; Saut si Bruleur Allum
	rjmp H_Repos
Br:
B_Sec:	
	lds r16,Tps_Bruleur+2	; Charge secondes
	inc r16
	mov r17,r16
	andi r17,0x0F		
	cpi r17,0x0A		; passage aprs 9 ?
	breq B_Sec_Dig_Suiv
	sts Tps_Bruleur+2,r16
	rjmp Fin_Br

B_Sec_Dig_Suiv:
	andi r16,0xF0		; Remise  0 units du digit
	swap r16
	inc r16			; Incremente dizaines du digit
	swap r16
	mov r17,r16
	andi r17,0xF0
	cpi r17,0x60		; 60 Secondes
	breq B_Min
	sts Tps_Bruleur+2,r16
	rjmp Fin_Br

B_Min:
	clr r16
	sts Tps_Bruleur+2,r16	; Sauve secondes  0
	lds r16,Tps_Bruleur+1	; Charge Minutes
	inc r16
	mov r17,r16
	andi r17,0x0F		
	cpi r17,0x0A		; passage aprs 9 ?
	breq B_Min_Dig_Suiv
	sts Tps_Bruleur+1,r16
	rjmp Fin_Br

B_Min_Dig_Suiv:
	andi r16,0xF0		; Remise  0 units du digit
	swap r16
	inc r16			; Incremente dizaines du digit
	swap r16
	mov r17,r16
	andi r17,0xF0
	cpi r17,0x60		; 60 Minutes
	breq B_Heure
	sts Tps_Bruleur+1,r16	; Sauve Minutes  0
	rjmp Fin_Br

B_Heure:
	clr r16
	sts Tps_Bruleur+1,r16	; Sauve Minutes  0
	lds r16,Tps_Bruleur	; Charge Heures
	inc r16
	mov r17,r16
	andi r17,0x0F		
	cpi r17,0x0A		; passage aprs 9 ?
	breq B_Heure_Dig_Suiv
	sts Tps_Bruleur,r16
	rjmp Fin_Br

B_Heure_Dig_Suiv:
	andi r16,0xF0		; Remise  0 units du digit
	swap r16
	inc r16			; Incremente dizaines du digit
	swap r16
	mov r17,r16
	andi r17,0xF0
	cpi r17,0xA0		; 99 Heures
	breq B_H
	sts Tps_Bruleur,r16
	rjmp Fin_Br
B_H:
	clr r16
	sts Tps_Bruleur,r16	; Sauve Heures  0

Fin_Br:

H_Repos:
	sbrc DRAPEAUX,3		; Saut si Repos en cours
	rjmp Fin_Horodateur

R_Sec:	
	lds r16,Tps_Repos+3	; Charge secondes
	inc r16
	mov r17,r16
	andi r17,0x0F		
	cpi r17,0x0A		; passage aprs 9 ?
	breq R_Sec_Dig_Suiv
	sts Tps_Repos+3,r16
	rjmp Fin_Re

R_Sec_Dig_Suiv:
	andi r16,0xF0		; Remise  0 units du digit
	swap r16
	inc r16			; Incremente dizaines du digit
	swap r16
	mov r17,r16
	andi r17,0xF0
	cpi r17,0x60		; 60 Secondes
	breq R_Min
	sts Tps_Repos+3,r16
	rjmp Fin_Re

R_Min:
	clr r16
	sts Tps_Repos+3,r16	; Sauve secondes  0
	lds r16,Tps_Repos+2	; Charge Minutes
	inc r16
	mov r17,r16
	andi r17,0x0F		
	cpi r17,0x0A		; passage aprs 9 ?
	breq R_Min_Dig_Suiv
	sts Tps_Repos+2,r16
	rjmp Fin_Re

R_Min_Dig_Suiv:
	andi r16,0xF0		; Remise  0 units du digit
	swap r16
	inc r16			; Incremente dizaines du digit
	swap r16
	mov r17,r16
	andi r17,0xF0
	cpi r17,0x60		; 60 Minutes
	breq R_Heure
	sts Tps_Repos+2,r16	; Sauve Minutes  0
	rjmp Fin_Re

R_Heure:
	clr r16
	sts Tps_Repos+2,r16	; Sauve Minutes  0
	lds r16,Tps_Repos+1	; Charge Heures
	inc r16
	mov r17,r16
	andi r17,0x0F		
	cpi r17,0x0A		; passage aprs 9 ?
	breq R_Heure_Dig_Suiv
	sts Tps_Repos+1,r16
	rjmp Fin_Re

R_Heure_Dig_Suiv:
	andi r16,0xF0		; Remise  0 units du digit
	swap r16
	inc r16			; Incremente dizaines du digit
	swap r16
	mov r17,r16
	andi r17,0xF0
	cpi r17,0x90		; 99 Heures
	breq R_Heure2
	sts Tps_Repos+1,r16
	rjmp Fin_Re

R_Heure2:
	clr r16
	sts Tps_Repos+1,r16	; Sauve Minutes  0
	lds r16,Tps_Repos	; Charge Heures
	inc r16
	mov r17,r16
	andi r17,0x0F		
	cpi r17,0x0A		; passage aprs 9 ?
	breq R_Heure2_Dig_Suiv
	sts Tps_Repos,r16
	rjmp Fin_Re

R_Heure2_Dig_Suiv:
	andi r16,0xF0		; Remise  0 units du digit
	swap r16
	inc r16			; Incremente dizaines du digit
	swap r16
	mov r17,r16
	andi r17,0xF0
	cpi r17,0x90		; 99 Heures
	breq R_H
	sts Tps_Repos,r16
	rjmp Fin_Re
R_H:
	clr r16
	sts Tps_Repos,r16	; Sauve Heures  0

Fin_Re:


Fin_Horodateur:


Fin_Seconde:


Clignotement:
	;---------------- Clignotement carr noir si bruleur actif et page 0 ----------------
	ldi r16,50
	inc Div_Clign
	cp Div_Clign,r16	; 0,5 seconde ?
        brne Fin_Clignotement	; Si non fin
	clr Div_Clign		; Si Oui Div_Clign=0

	sbrs DRAPEAUX,2		; saut si thermostat en route
	rjmp Fin_Clignotement	; Sinon pas de test  faire

	mov r16,DRAPEAUX
	andi r16,0x03
	brne Fin_Clignotement	; Si ce n'est pas la page 0

	sbrs DRAPEAUX,5		; Si bruleur allum : saut
	rjmp PasBruleur		; Sinon Eteint

	sbrc DRAPEAU2,6		; Sauvegarde=1 ?
	rjmp Test_Cli		; Si oui Faire le test de clignotement
	sbr DRAPEAU2,0xC0	; Lever Drapeau de clignotement
				; Mettre sauvegarde 1
	rjmp Test_Cli

PasBruleur:
	sbrs DRAPEAU2,6		; Sauvegarde=1 ?
	rjmp Test_Cli		; Si Non faire test de clignotement
	cbr DRAPEAU2,0xC0	; baisser le drapeau de clignotement
				; Mettre sauvegarde  0
	ldi r16,0x88
	rcall PROG_LCD
	ldi r16,' '		; Effacer point de clignotement
	rcall DATA_LCD
	ldi r16,0xC8
	rcall PROG_LCD
	ldi r16,' '		; Effacer point de clignotement
	rcall DATA_LCD

Test_Cli:
	sbrs DRAPEAU2,7		; Si clignotement activ : saut
	rjmp Fin_Clignotement	; Sinon inactif : ne fait rien
	sbrc DRAPEAU2,5		; Si clignoteur=lg1 saut
	rjmp Cl_Lg2		; Sinon ligne 2

	ldi r16,0x88
	rcall PROG_LCD
	ldi r16,0xFF		; Afficher point de clignotement lg1
	rcall DATA_LCD
	ldi r16,0xC8
	rcall PROG_LCD
	ldi r16,' '		; Effacer point de clignotement lg2
	rcall DATA_LCD
	sbr DRAPEAU2,0x20	; Ligne 2 au prochain passage
	rjmp Fin_Clignotement

Cl_Lg2:
	ldi r16,0x88
	rcall PROG_LCD
	ldi r16,' '		; Effacer point de clignotement lg1
	rcall DATA_LCD
	ldi r16,0xC8
	rcall PROG_LCD
	ldi r16,0xFF		; Afficher point de clignotement lg2
	rcall DATA_LCD
	cbr DRAPEAU2,0x20	; Ligne 1 au prochain passage


Fin_Clignotement:
	;---------------- Autres traitements temporiss -------------------------------------
Traitements:     

Fin_Timer1:
	pop temp
	out SREG,temp		; Dpiler SREG
	pop temp		; Dpiler temp
	reti


;******************************************************************************************
;			SOUS PROGRAMMES
;******************************************************************************************
;_________________________ SOUS PROGRAMMES Gestion LCD _______________________________
.include "LCDCLAV.sub"		; Routines de gestionnaire LCD + CLAVIER
.include "DS1620.SUB"		; Module de Gestion sonde DS1620
.include "Affiche.asm"		; Sous programmes de gestion de l'affichage
.include "clavier.asm"		; Sous programmes de gestion du clavier
.include "Automat.asm"		; Sous programmes de gestion automatique de la consigne

;******************************************************************************************
;			TABLES DE CARACTERES, TABLE ROM.....
;******************************************************************************************
BV1:	.db "** Aqua-Regul **",0
BV2: 	.db "Par I.G.Software",0
